@@ -246,13 +246,13 @@ def precheck_for_project(path_to_find):
         missing_license = [str(sub) for sub in set(report.files_without_licenses)]
         if not path_to_find.endswith(f"{os.sep}"):
             path_to_find += f"{os.sep}"
-        missing_license = [sub.replace(path_to_find, '') for sub in missing_license]
+        missing_license = [sub.replace(path_to_find, '', 1) for sub in missing_license]
 
         # File list that missing copyright text
         missing_copyright = [str(sub) for sub in set(report.files_without_copyright)]
         if not path_to_find.endswith(f"{os.sep}"):
             path_to_find += f"{os.sep}"
-        missing_copyright = [sub.replace(path_to_find, '') for sub in missing_copyright]
+        missing_copyright = [sub.replace(path_to_find, '', 1) for sub in missing_copyright]
     except Exception as ex:
         dump_error_msg(f"Error prechecker lint: {ex}", True)
 
@@ -271,7 +271,7 @@ def dump_error_msg(error_msg: str, exit=False):
 
 def init(path_to_find, output_path, file_list, need_log_file=True):
     global logger, _result_log
-    logger, _result_log = init_log(os.path.join(output_path, f"fosslight_log_{_start_time}.txt"),
+    logger, _result_log = init_log(os.path.join(output_path, f"fosslight_log_pre_{_start_time}.txt"),
                                    need_log_file, logging.INFO, logging.DEBUG, PKG_NAME, path_to_find)
     if file_list:
         _result_log["File list to check"] = file_list
